<nav class="subnavbar navbar-default navbar-fixed-top" role="navigation">
  <div class="container">
    <div class="">
      <ul class="nav navbar-nav" id="feedme-menu">
        <li class="hidden-xs"><a href="{% url "index" %}">FeedMe</a></li>
        {% if is_admin %}
          <li><a class="hidden-xs" href="{% url "admin" %}">Admin</a></li>
        {% endif %}
        <li><a href="#">{{ user.username }}: {{ user.balance.get_balance_string }}</a></li>
        {% if not user.is_authenticated %}
          <li class="pull-right">
            <form method="post" action="">
              {% csrf_token %}
              <input type="text" name="act" value="log_in" hidden>
              <input type="text" name="username" placeholder="Username">
              <input type="password" name="password" placeholder="********">
              <input type="submit" name="log_in" value="Log in">
            </form>
          </li>
        {% endif %}
      </ul>
    </div>
  </div>
</nav>
